@@ -15,6 +15,7 @@ use IPC::System::Simple (); # for autodie && prereqs
 
 use File::chdir;
 use Path::Class;
+use Capture::Tiny 'capture_merged';
 
 use Test::DZil;
 
@@ -29,7 +30,14 @@ sub make_test_repo {
     unshift @commands, 'git init'
         unless $commands[0] =~ /git init/;
 
-    system "($_) 2> /dev/null > /dev/null" for @commands;
+    # If we're not a code ref, make us one.
+    @commands =
+        map { my $x = $_; ref $x ? $x : sub { system "($x)" } }
+        @commands
+        ;
+
+    # this is just to keep things quiet...
+    capture_merged { $_->() } for @commands;
 
     return $repo_root;
 }
